%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function AnalysisLinearMenuSelected_m(app)
%%% Linear fitting
% The script is called by the fit menu callback on AnalysisFigure

app.analysisWindowClosed = false;

% Retrieve data to fit (from AnalysisFigure)
SelectAnalysisFitCoords(app);
% Choose transformation to be applied to data
SelectTransformationForFitting(app);

% Execute the fitting if the dialog window hasn't been closed
if ~app.analysisWindowClosed
  
  % Preallocating the fittings
  app.fitVariableLength = 1000;
  app.fitVariableNumber = size(app.fitYCoords,2);
  app.fitXResults = zeros(app.fitVariableLength,app.fitVariableNumber);
  app.fitYResults = zeros(app.fitVariableLength,app.fitVariableNumber);
  
  % Call the script that does the fitting (fminsearch)
  LinearFit(app);
  
  % Set the first sweep to be plotted
  app.fittedSpinner = 1;
  app.FittedSweepSpinner.Value = 1;
  
  % Apply inverse tranformation to data
  fitTransformationSwitch(app);
  
  % Plot the fitting
  SelectDataFittedToPlot(app);
  
  % Save fitted parameters in the axes object
  set(app.fitAxes,'userdata',app.linParam)
  % Set flag: AnalysisFigure has been fitted
  app.fitPerformed = true;
  
end
end
