%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function AnalysisWindowClosing(~,~,app,a,f)
%%% When an AnalysisFigure is closed, this function deletes the data of the
%%% analysis from the specific struct and its handle 

  if startsWith(a.Title.String,'I/V')
    app.IVAnalysisResults(str2double(a.Title.String(end))).current = [];
    app.IVAnalysisResults(str2double(a.Title.String(end))).voltage = [];
    app.IVAnalysisResults(str2double(a.Title.String(end))).title = [];
    app.IVAnalysisResults(str2double(a.Title.String(end))).axesUnits = [];
  end

  if startsWith(a.Title.String,'Conductance')
    app.ConductanceAnalysisResults(str2double(a.Title.String(end))).conductance = [];
    app.ConductanceAnalysisResults(str2double(a.Title.String(end))).voltage = [];
    app.ConductanceAnalysisResults(str2double(a.Title.String(end))).title = [];
    app.ConductanceAnalysisResults(str2double(a.Title.String(end))).axesUnits = [];
  end
  
  if startsWith(a.Title.String,'Histogram')
    app.HistogramAnalysisResults(str2double(a.Title.String(end))).count = [];
    app.HistogramAnalysisResults(str2double(a.Title.String(end))).binCenters = [];
    app.HistogramAnalysisResults(str2double(a.Title.String(end))).title = [];
    app.HistogramAnalysisResults(str2double(a.Title.String(end))).axesUnits = [];
  end
  
  if startsWith(a.Title.String,'PSD')
    app.PSDAnalysisResults(str2double(a.Title.String(end))).currentPSD = [];
    app.PSDAnalysisResults(str2double(a.Title.String(end))).frequencyVector = [];
    app.PSDAnalysisResults(str2double(a.Title.String(end))).title = [];
    app.PSDAnalysisResults(str2double(a.Title.String(end))).axesUnits = [];
  end
  
  if startsWith(a.Title.String,'Dependence')
    app.DependenceAnalysisResults(str2double(a.Title.String(end))).xDep = [];
    app.DependenceAnalysisResults(str2double(a.Title.String(end))).yDep = [];
    app.DependenceAnalysisResults(str2double(a.Title.String(end))).title = [];
    app.DependenceAnalysisResults(str2double(a.Title.String(end))).axesUnits = [];
  end
  
  % Delete cleared analysis from handle list
  app.AnalysisFigureList(app.AnalysisFigureList == f) = [];
end

