%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function CursorNumberSpinnerValueChanging_m(app, event)
% Check if the number of cursors was inserted manually or using the
% spinner, because data type changes; in case it is a string, convert it to
% double
if ischar(event.Value)
  ValueOfEvent = str2double(event.Value);
else
  ValueOfEvent = event.Value;
end

cursorsOptions = cell(ValueOfEvent,1);
% hold on
set(app.CurrentAxes,'NextPlot','add')
n = ValueOfEvent+1;
% Set cursors abscissa as length of signal divided by number of cursors +1
% (if one cursor is selected, it will be placed at the half of the signal)
x_cursors = repmat(app.dataTimeVect(end)./n,1,2);
% Cursor is set to be as high as axes
y_cursors = get(app.CurrentAxes,'Ylim');

% Delete existing cursor labels
delete(app.curLabel)

for idx=1:ValueOfEvent
  
  % Define string for drop down menu
  cursorsOptions{idx} = ['cursor ', num2str(idx)];
  
  % If idx > of number of previously existing cursors, plot a new cursor,
  % else update existing ones
  if idx>numel(app.cursorsLine)
    app.cursorsLine(idx) = plot(app.CurrentAxes,x_cursors*idx,y_cursors,'r');
  else
    set(app.cursorsLine(idx),'xdata',x_cursors*idx,'ydata',y_cursors)
  end
  % Assign labels to cursors
  app.curLabel(idx) = text(app.CurrentAxes,x_cursors(1)*idx-0.05,(y_cursors(2)+y_cursors(2)*0.1),num2str(idx),'Color','red');
  
end
% Assign items to drop down menu
app.CursorDropDown.Items = cursorsOptions;
% hold on
set(app.CurrentAxes,'NextPlot','replace')

% When selecting less cursors than the ones previously existing, delete the
% ones no more selected
for idx = ValueOfEvent+1:app.CursorNumberSpinner.Limits(2)
  
  if idx<=numel(app.cursorsLine)
    delete(app.cursorsLine(idx)) % delete the graphic object only...
  end
  
end
% ...also delete the values in the variables
app.cursorsLine(ValueOfEvent+1:end) = [];
app.curLabel(ValueOfEvent+1:end) = [];

% Update spinner value with position of selected cursor
CursorDropDownValueChanged_m(app);

% Enable drop down menu and spinner if at least one cursor is selected
if ValueOfEvent>0
  app.CursorDropDown.Enable = 'on';
  app.x_cursorSpinner.Enable = 'on';
else
  app.CursorDropDown.Enable = 'off';
  app.x_cursorSpinner.Enable = 'off';
  app.x_cursorSpinner.Value = 0;
end

% Assign a "tag" to cursors and labels so that can be recognized when
% moving with mouse (plotted lines without tag can't be moved)
set(app.cursorsLine,'userdata',"cursor")
set(app.curLabel,'userdata',"cursor")

% Create handles to be passed to EDAmatUIFigure mouse action callbacks
handles.app = app;
% Get handles of lines plotted on CurrentAxes
lines = get(app.CurrentAxes,'children');
% Only pass the ones with "cursor" tag
mouse_cursors = [];
% Check every plotted line
for i = 1:length(lines)
  % Do not select data plots
  if ~isempty(get(lines(i),'userData'))
    % Only select cursors, not labels
    if strcmpi(get(lines(i),'userData'),"cursor") && ~strcmpi(get(lines(i),'type'),"text")
      % Concatenate handles in a struct
      mouse_cursors = [mouse_cursors lines(i)];
    end
  end
end

% cursor # 1 must be the first object
handles.plotHandles = fliplr(mouse_cursors);
% save the data, so that they can be passed to UIFigure callbacks
guidata(app.EDAmatUIFigure,handles);
end
