%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function DataInfoMenuSelected_m(app)
%%% This script displays basic data information

% Sampling frequency
fSamp = 1/(app.samplingTime);
% Number of samples per sweep
nSampPerSweep = app.sweepLength;
% Number of sweeps
nSweep = app.sweepsNumber;
% Channels number
nChans = app.channelsNumber;
% Define time vector in ms
app.dataTimeVect = ((1:app.sweepLength)*app.samplingTime)';
% Total number of samples
nSampTot = nSampPerSweep*nSweep;
% File name
if iscell(app.fileName)
  % if more than one file has been loaded, change the name to finish in
  % "avg", since all the analysis is done on the average of loaded raw
  % data
  nameOfFile = [app.fileName{1} '_avg'];
else
  nameOfFile = app.fileName;
end

% Create the struct
info={['File Name: ', nameOfFile ];...
  ['Sampling frequency: ', num2str(fSamp) ' kHz'];
  ['Number of samples per sweep: ', num2str(nSampPerSweep)];
  ['Number of sweeps: ',num2str(nSweep)];
  ['Number of channels: ',num2str(nChans)];
  ['Number of samples: ',num2str(nSampTot)]};

% No action can be done until information window is closed
o.WindowStyle = 'modal';
% Select no interpreter, otherwise msgbox interprets underscores as
% subscripts
o.Interpreter = 'none';
% Display info
msgbox(info,'Data Info','help',[],[],o)
end
