%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function DependenceAnalysisMenuSelected_m(app)
%%% Analysis: Dependence graph -> plot variables and fitted parameters one
%%% against the other
InitialAnalysisControls(app);

% Execute Analysis only if cursors are in the right position
if app.cursorsOk
  % Dialog to choose the normalization to be applied to data
  d = dialog('Position',[300 300 500 300],'Name','Dependence Analysis Data Selection','CloseRequestFcn',{@DataSelectionWindowClosing, app});
  
  txtI = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[5 250 250 25],...
    'String','Select in which point calculate I');
  
  txtV = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[255 250 250 25],...
    'String','Select in which point calculate the V');
  
  txtNorm = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[5 180 250 20],...
    'String','Select the normalization on I');
  
  txtPlot = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[130 110 250 20],...
    'String','Select data to plot');
  
  txtX = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[50 67 50 20],...
    'String','X');
  
  txtY = uicontrol('Parent',d,...
    'Style','text',...
    'Position',[280 67 50 20],...
    'String','Y');
  
  popupStringIV = {'mean','max','min'};
  popupStringNorm = {'Not normalized','max [0 1]','Cell capacitance'};
  popupStringPlotY = {'I','V'}';
  % Display as many popup strings as the respective executed fittings
  if ~isempty(app.expParam)
    popupStringPlotY = [popupStringPlotY;  fieldnames(app.expParam)];
  end
  if ~isempty(app.gaussParam)
    popupStringPlotY = [popupStringPlotY;  fieldnames(app.gaussParam)];
  end
  if ~isempty(app.linParam)
    popupStringPlotY = [popupStringPlotY;  fieldnames(app.linParam)];
  end
  if ~isempty(app.boltzParam)
    popupStringPlotY = [popupStringPlotY;  fieldnames(app.boltzParam)];
  end
  
  % Every variable or parameter can be plotted on x or y axis
  popupStringPlotX = popupStringPlotY;
  % V is displayed by default on the x axis
  popupStringPlotX{1} = 'V';
  % I is displayed by default on the y axis
  popupStringPlotX{2} = 'I';
  
  popupI = uicontrol('Parent',d,...
    'Style','popup',...
    'Position',[75 230 100 20],...
    'String',popupStringIV,...
    'Callback',{@popupI_callback,app});
  
  popupV = uicontrol('Parent',d,...
    'Style','popup',...
    'Position',[325 230 100 20],...
    'String',popupStringIV,...
    'Callback',{@popupV_callback,app});
  
  popupNorm = uicontrol('Parent',d,...
    'Style','popup',...
    'Position',[75 160 100 20],...
    'String',popupStringNorm,...
    'Callback',{@popupNorm_callback,app});
  
  popupPlotX = uicontrol('Parent',d,...
    'Style','popup',...
    'Position',[85 70 90 20],...
    'String',popupStringPlotX,...
    'Callback',{@popupPlotX_callback,app});
  
  popupPlotY = uicontrol('Parent',d,...
    'Style','popup',...
    'Position',[335 70 90 20],...
    'String',popupStringPlotY,...
    'Callback',{@popupPlotY_callback,app});
  
  btn = uicontrol('Parent',d,...
    'Style','pushbutton',...
    'Position',[225 20 70 20],...
    'String','Select',...
    'Callback',{@select_btn_callback,app});
  
  % Default: 1-> mean
  app.Ipoint = app.POINT_MEAN;
  % Default: 1-> mean
  app.Vpoint = app.POINT_MEAN;
  % Default: 1-> not normalized
  app.normType = app.NORM_TYPE_NOT;
  % V is displayed by default on the x axis
  app.xDepType = app.DEP_TYPE_V;
  % I is displayed by default on the y axis
  app.yDepType = app.DEP_TYPE_I;
  
  % Wait for d to close before running to completion
  uiwait(d);
  
  % Execute the fitting only if the dialog window hasn't been closed
  if ~app.analysisWindowClosed
    
    % Increment number of executed Analysis
    app.DepIndex = app.DepIndex+1;
    % Plot on analysis figure
    f = AnalysisFigure;
    % Keep figure handle in a variable
    app.AnalysisFigureList = [app.AnalysisFigureList, f];
    % Retrieve axes handle
    a = f.getAxes;
    % Assign window closing function to AnalysisFigure
    a.DeleteFcn = {@AnalysisWindowClosing, app, a, f};
    % hold on
    set(a, 'nextplot', 'add');
    
    % Plot variables or parameters to the shortest of the two variables
    % selected
    if length(app.xDep) ~= length(app.yDep)
      % Get smaller length
      minLength = min(length(app.xDep), length(app.yDep));
      % Extract values
      app.xDep = app.xDep(1:minLength);
      app.yDep = app.yDep(1:minLength);
    end
    
    plot(a,app.xDep,app.yDep,'bo')
    % Plot properties
    grid(a,'on')
    title(a,['Dependence graph ' num2str(app.DepIndex)])
    xlabel(a,app.xLab)
    ylabel(a,app.yLab)
    
    % Pass data to AnalysisAxes
    f.assignDataToPlot(app.xDep,app.yDep,0);
    % Pass ticks data to AnalysisAxes
    f.savePlotTicks;
    % Pass labels to AnalysisAxes
    f.xUnitLabel = app.xLab;
    f.yUnitLabel = app.yLab;
    % Pass normalization type to AnalysisAxes
    f.normType = app.normType;
    % Save data in a struct to be exported
    tempStruct.xDep = app.xDep;
    tempStruct.yDep = app.yDep;
    tempStruct.axes = a;
    tempStruct.title = ['Dependence graph ' num2str(app.DepIndex)];
    tempStruct.axesUnits.X = app.xLab;
    tempStruct.axesUnits.Y = app.yLab;
    % Concatenate executed Analysis in a struct
    app.DependenceAnalysisResults = [app.DependenceAnalysisResults; tempStruct];
    
  end
  
end
end

function popupI_callback(popup,~,app)
% Set in which point to do the analysis
idx = popup.Value;
popup_items = popup.String;
choice = string(popup_items{idx});
if choice == "mean"
  app.Ipoint = app.POINT_MEAN;
  
elseif choice == "max"
  app.Ipoint = app.POINT_MAX;
  
elseif choice == "min"
  app.Ipoint = app.POINT_MIN;
end

end

function popupV_callback(popup,~,app)
% Set in which point to do the analysis
idx = popup.Value;
popup_items = popup.String;
choice = string(popup_items{idx});
if choice == "mean"
  app.Vpoint = app.POINT_MEAN;
  
elseif choice == "max"
  app.Vpoint = app.POINT_MAX;
  
elseif choice == "min"
  app.Vpoint = app.POINT_MIN;
end

end

function popupNorm_callback(popup,~,app)
% Set the normalization
idx = popup.Value;
popup_items = popup.String;
choice = string(popup_items{idx});
if startsWith(choice, "Not")
  app.normType = app.NORM_TYPE_NOT;
  
elseif startsWith(choice, "max")
  app.normType = app.NORM_TYPE_MAX;
  
elseif startsWith(choice, "Cell")
  app.normType = app.NORM_TYPE_CELL;
end

end

function popupPlotX_callback(popup,~,app)
% Set the type of selected x variable
idx = popup.Value;
popup_items = popup.String;
choice = string(popup_items{idx});

if strcmpi(choice, "I")
  app.xDepType = app.DEP_TYPE_I;
  
elseif strcmpi(choice, "V")
  app.xDepType = app.DEP_TYPE_V;
  
elseif strcmpi(choice, "ExpAmplitude")
  app.xDepType = app.DEP_TYPE_ExpAmp;
  
elseif strcmpi(choice, "TimeConstant")
  app.xDepType = app.DEP_TYPE_TAU;
  
elseif strcmpi(choice, "FullValue")
  app.xDepType = app.DEP_TYPE_FULL;
  
elseif strcmpi(choice, "GaussAmplitude")
  app.xDepType = app.DEP_TYPE_GaussAmp;
  
elseif strcmpi(choice, "mean")
  app.xDepType = app.DEP_TYPE_MEAN;
  
elseif strcmpi(choice, "std")
  app.xDepType = app.DEP_TYPE_STD;
  
elseif strcmpi(choice, "Slope")
  app.xDepType = app.DEP_TYPE_SLOPE;
  
elseif strcmpi(choice, "yIntercept")
  app.xDepType = app.DEP_TYPE_INTERC;
  
elseif strcmpi(choice, "Bottom")
  app.xDepType = app.DEP_TYPE_BOTTOM;
  
elseif strcmpi(choice, "Top")
  app.xDepType = app.DEP_TYPE_TOP;
  
elseif strcmpi(choice, "VHalf")
  app.xDepType = app.DEP_TYPE_VHALF;
  
elseif strcmpi(choice, "BoltzSlope")
  app.xDepType = app.DEP_TYPE_BoltzSlope;
  
end

end

function popupPlotY_callback(popup,~,app)
% Set the type of selected y variable
idx = popup.Value;
popup_items = popup.String;
choice = string(popup_items{idx});

if strcmpi(choice, "I")
  app.yDepType = app.DEP_TYPE_I;
  
elseif strcmpi(choice, "V")
  app.yDepType = app.DEP_TYPE_V;
  
elseif strcmpi(choice, "ExpAmplitude")
  app.yDepType = app.DEP_TYPE_ExpAmp;
  
elseif strcmpi(choice, "TimeConstant")
  app.yDepType = app.DEP_TYPE_TAU;
  
elseif strcmpi(choice, "FullValue")
  app.yDepType = app.DEP_TYPE_FULL;
  
elseif strcmpi(choice, "GaussAmplitude")
  app.yDepType = app.DEP_TYPE_GaussAmp;
  
elseif strcmpi(choice, "mean")
  app.yDepType = app.DEP_TYPE_MEAN;
  
elseif strcmpi(choice, "std")
  app.yDepType = app.DEP_TYPE_STD;
  
elseif strcmpi(choice, "Slope")
  app.yDepType = app.DEP_TYPE_SLOPE;
  
elseif strcmpi(choice, "yIntercept")
  app.yDepType = app.DEP_TYPE_INTERC;
  
elseif strcmpi(choice, "Bottom")
  app.yDepType = app.DEP_TYPE_BOTTOM;
  
elseif strcmpi(choice, "Top")
  app.yDepType = app.DEP_TYPE_TOP;
  
elseif strcmpi(choice, "VHalf")
  app.yDepType = app.DEP_TYPE_VHALF;
  
elseif strcmpi(choice, "BoltzSlope")
  app.yDepType = app.DEP_TYPE_BoltzSlope;
  
end

end

function select_btn_callback(~,~,app)

% Calculate current values for I/V graph in the selected point
switch app.Ipoint
  case app.POINT_MEAN % mean
    app.IdepGraph = mean(app.current(app.cursorsTimeVect,:))';
    
  case app.POINT_MAX % max
    app.IdepGraph = max(app.current(app.cursorsTimeVect,:))';
    
  case app.POINT_MIN % min
    app.IdepGraph = min(app.current(app.cursorsTimeVect,:))';
    
end

% Calculate voltage values for I/V graph in the selected point
switch app.Vpoint
  case app.POINT_MEAN % mean
    app.VdepGraph = mean(app.voltage(app.cursorsTimeVect,:))';
    
  case app.POINT_MAX % max
    app.VdepGraph = max(app.voltage(app.cursorsTimeVect,:))';
    
  case app.POINT_MIN % min
    app.VdepGraph = min(app.voltage(app.cursorsTimeVect,:))';
    
end

% Apply normalization
switch app.normType
  case app.NORM_TYPE_NOT % Not normalized
    % nothing to do
  case app.NORM_TYPE_MAX % max
    app.IdepGraph = app.IdepGraph./max(app.IdepGraph);
  case app.NORM_TYPE_CELL % Cell capacitance
    % Check if Cell capacitance value was inserted, otherwise use default
    % value = 1
    if isempty(app.cellCapacitance) || app.cellCapacitance == 0 || app.cellCapacitance == 1
      app.cellCapacitance = 1;
    end
    app.IdepGraph = app.IdepGraph/app.cellCapacitance;
end

% Set the selected variable with its label as x
switch app.xDepType
  case app.DEP_TYPE_I
    app.xDep = app.IdepGraph;
    app.xLab = {'I ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_V
    app.xDep = app.VdepGraph;
    app.xLab = {'V ' ['[' app.voltageAxesLabel ']']};
    
  case app.DEP_TYPE_ExpAmp
    app.xDep = cell2mat({app.expParam.ExpAmplitude});
    app.xLab = {'Amplitude ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_TAU
    app.xDep = cell2mat({app.expParam.TimeConstant});
    app.xLab = {'Time constant' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_FULL
    app.xDep = cell2mat({app.expParam.FullValue});
    app.xLab = {'Full Value ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_GaussAmp
    app.xDep = cell2mat({app.gaussParam.GaussAmplitude});
    app.xLab = {'Amplitude ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_MEAN
    app.xDep = cell2mat({app.gaussParam.mean});
    app.xLab = {'Mean ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_STD
    app.xDep = cell2mat({app.gaussParam.std});
    app.xLab = {'Standard deviation ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_SLOPE
    app.xDep = cell2mat({app.linParam.Slope});
    app.xLab = {'Slope ' ['[' app.currentAxesLabel '/' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_INTERC
    app.xDep = cell2mat({app.linParam.yIntercept});
    app.xLab = {'Intercept ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_BOTTOM
    app.xDep = cell2mat({app.boltzParam.Bottom});
    app.xLab = {'Bottom ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_TOP
    app.xDep = cell2mat({app.boltzParam.Top});
    app.xLab = {'Top ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_VHALF
    app.xDep = cell2mat({app.boltzParam.VHalf});
    app.xLab = {'Half Value ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_BoltzSlope
    app.xDep = cell2mat({app.boltzParam.BoltzSlope});
    app.xLab = {'Slope ' ['[' app.currentAxesLabel '/' app.timeAxesLabel ']']};
    
end

% Set the selected variable with its label as y
switch app.yDepType
  case app.DEP_TYPE_I
    app.yDep = app.IdepGraph;
    % Assign the right label, depending on normalization
    switch app.normType
      case app.NORM_TYPE_NOT % not norm
        app.yLab = {'I ' ['[' app.currentAxesLabel ']']};
      case app.NORM_TYPE_MAX % [0 1]
        app.yLab = {'Fractional Activation'};
      case app.NORM_TYPE_CELL % Cell capacitance
        app.yLab = {'Current Density ' ['[' app.currentAxesLabel '/pF]']};
    end
  case app.DEP_TYPE_V
    app.yDep = app.VdepGraph;
    % Assign the right label, depending on normalization
    switch app.normType
      case app.NORM_TYPE_NOT % not norm
        app.yLab = {'V ' ['[' app.voltageAxesLabel ']']};
      case app.NORM_TYPE_MAX % [0 1]
        app.yLab = {'Fractional Activation'};
      case app.NORM_TYPE_CELL % Cell capacitance
        app.yLab = {'V ' ['[' app.voltageAxesLabel '/pF]']};
    end
  case app.DEP_TYPE_ExpAmp
    app.yDep = cell2mat({app.expParam.ExpAmplitude});
    app.yLab = {'Amplitude ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_TAU
    app.yDep = cell2mat({app.expParam.TimeConstant});
    app.yLab = {'Time constant' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_FULL
    app.yDep = cell2mat({app.expParam.FullValue});
    app.yLab = {'Full Value ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_GaussAmp
    app.yDep = cell2mat({app.gaussParam.GaussAmplitude});
    app.yLab = {'Amplitude ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_MEAN
    app.yDep = cell2mat({app.gaussParam.mean});
    app.yLab = {'Mean ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_STD
    app.yDep = cell2mat({app.gaussParam.std});
    app.yLab = {'Standard deviation ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_SLOPE
    app.yDep = cell2mat({app.linParam.Slope});
    app.yLab = {'Slope ' ['[' app.currentAxesLabel '/' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_INTERC
    app.yDep = cell2mat({app.linParam.yIntercept});
    app.yLab = {'Intercept ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_BOTTOM
    app.yDep = cell2mat({app.boltzParam.Bottom});
    app.yLab = {'Bottom ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_TOP
    app.yDep = cell2mat({app.boltzParam.Top});
    app.yLab = {'Top ' ['[' app.currentAxesLabel ']']};
    
  case app.DEP_TYPE_VHALF
    app.yDep = cell2mat({app.boltzParam.VHalf});
    app.yLab = {'Half Value ' ['[' app.timeAxesLabel ']']};
    
  case app.DEP_TYPE_BoltzSlope
    app.yDep = cell2mat({app.boltzParam.BoltzSlope});
    app.yLab = {'Slope ' ['[' app.currentAxesLabel '/' app.timeAxesLabel ']']};
    
end
% Close dialog
delete(gcf)
end
