%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function ExponentialMenuSelected_m(app)
%%%%% Exponential fitting
% The script is called by the fit menu callback on the GUIfigure

% Retrieve current data to be fitted
SelectFitCoords(app);

% Execute Fitting only if cursors are in the right position
if app.cursorsOk
  % Choose transformation to be applied to data
  SelectTransformationFor_EXP_Fitting(app);
  
  % Execute the fitting only if the dialog window hasn't been closed
  if ~app.analysisWindowClosed
    
    % Allocate variables
    app.fitXResults = zeros(app.fitVariableLength, app.fitVariableNumber);
    app.fitYResults = zeros(app.fitVariableLength, app.fitVariableNumber);
    
    % Call the script that does the fitting (fminsearch)
    ExponentialFit(app);
    
    % Display UIfigure over other windows
    figure(app.EDAmatUIFigure)
    % Set the first sweep to be plotted
    app.fittedSpinner = 1;
    app.FittedSweepSpinner.Value = 1;
    
    % Apply inverse tranformation to data
    fitTransformationSwitch(app);
    
    % Plot the fitting
    SelectDataFittedToPlot(app);
    
  end
  
end
end
