%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function LoadControls(app)
%%% Control if a file is loaded after another one

%%% Clear UIfigures
% Get figures handles
figHandles = findall(groot, 'Type', 'figure');
% Check if a figure is an analysis figure and in this case, close it; this 
% allows EDAmatUIFigure to be left open  
for idx = 1:length(figHandles)
  if strcmpi(get(figHandles(idx),'Name'),"UI Figure")
    close(figHandles(idx))
  end
end
% Clear stored figure handles
app.AnalysisFigureList = [];

%%% Keep cursors as previously selected, but clear all plots
% Get lines handles
a = get(app.CurrentAxes,'children'); 
% Check if a line has the "cursor" tag, in the other case, delete its
% graphic object (data will be overwritten during loading of a new file)
for idx = 1:length(a)
  line = a(idx);
  if ~strcmpi(get(line,'userdata'),"cursor")
    delete(line)
  end
end

%%% Clear GUI fields and 
app.dataTimeVect = [];
app.infoAbfLoad  = [];
app.sweepLength  = [];
app.samplingTime = [];
app.current      = [];
app.voltage      = [];
app.IVpoint      = [];
app.Ipoint       = [];
app.Vpoint       = [];

% Reset analysis counts
app.IVindex      = 0;
app.GVindex      = 0;
app.HISTindex    = 0;
app.PSDindex     = 0;
app.DepIndex     = 0;

% Disable spinners and fields
app.FittedSweepSpinner.Value = 1;
app.FittedSweepSpinner.Enable = 'off';
app.FittedSweepSpinnerLabel.Enable = 'off';

if ~isempty(app.RestingPotentialField.Value)
  app.RestingPotentialField.Value = 0;
  app.RestingPotentialField.Enable = 'off';
  app.RestingPotentialmVLabel.Enable = 'off';
  app.restingPotential = [];
  app.WarningLabel.Visible = 'on';
end

if ~isempty(app.CellCapacitanceField.Value)
  app.CellCapacitanceField.Value = 1;
  app.cellCapacitance = 1;
  app.CapacitanceWarningLabel.Visible = 'on';
end

if ~isempty(app.ExperimentalconditionField.Value)
  app.ExperimentalconditionField.Value = '';
end

%%% Clear fitting variables and parameters structs
app.fitDataType    = [];
app.fitDataIdx     = [];
app.fitXCoords     = [];
app.fitYCoords     = [];
app.fitXResults    = [];
app.fitYResults    = [];
app.fittedSpinner  = [];
app.fittedLine     = [];
app.expType        = [];

if ~isempty(app.expParam)
  app.expParam = struct([]);
end

if ~isempty(app.gaussParam)
  app.gaussParam = struct([]);
end

if ~isempty(app.linParam)
  app.linParam = struct([]);
end

if ~isempty(app.boltzParam)
  app.boltzParam = struct([]);
end

%%% Clear analysis variables and structs
app.fitXTrasfType = [];
app.fitYTrasfType = [];
app.xDep          = [];
app.yDep          = [];

if ~isempty(app.IVAnalysisResults)
  app.IVAnalysisResults = struct([]);
end

if ~isempty(app.ConductanceAnalysisResults)
  app.ConductanceAnalysisResults = struct([]);
end

if ~isempty(app.HistogramAnalysisResults)
  app.HistogramAnalysisResults = struct([]);
end

if ~isempty(app.PSDAnalysisResults)
  app.PSDAnalysisResults = struct([]);
end

if ~isempty(app.DependenceAnalysisResults)
  app.DependenceAnalysisResults = struct([]);
end
end
