%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function LoadEdhActions(app, current, voltage, time, dataInfo)
%%% Converting to used units of measure :
% Current     -> [nA]
% Voltage     -> [mV]
% Time        -> [ms]
% Frequency   -> [kHz]
% Conductance -> [uS]

% Get time in ms from sampling rate in Hz
app.samplingTime = 1e3/dataInfo.samplingRateValue;
% Sampling frequency is in kHz
app.samplingFrequency = 1/app.samplingTime;
% I is channel 1
app.current = current;
% V is channel 2
app.voltage = voltage;
% Convert time from s to ms
app.dataTimeVect = time*1e3;
% Samples per sweep
app.sweepLength = size(app.current, 1);
% Sweeps number
app.sweepsNumber = size(app.voltage, 2);
% Channels number
app.channelsNumber = size(app.current, 2)/app.sweepsNumber;

% Check if current is in nA, else convert it to nA
if strcmpi(dataInfo.currentRangeUnit,'nA')
  % nothing to do
elseif strcmpi(dataInfo.currentRangeUnit,'pA')
  app.current = app.current/1e3;
end

% Define unit labels
app.currentAxesLabel = 'nA';
app.voltageAxesLabel = 'mV';
app.timeAxesLabel = 'ms';
app.freqAxesLAbel = 'kHz';
% conductance depends on I and V: [nA]/[mV] = [uS]
app.conductanceAxesLabel = 'uS';

% hold on
set(app.CurrentAxes,'nextplot','add')

% Plot current data
plot(app.CurrentAxes,app.dataTimeVect, app.current)
title(app.CurrentAxes,'Current')
xlabel(app.CurrentAxes,app.timeAxesLabel)
ylabel(app.CurrentAxes,app.currentAxesLabel)

% Plot voltage data
plot(app.VoltageAxes,app.dataTimeVect, app.voltage)
title(app.VoltageAxes,'Voltage')
xlabel(app.VoltageAxes,app.timeAxesLabel)
ylabel(app.VoltageAxes,app.voltageAxesLabel)

% Enable grids
grid(app.CurrentAxes, 'on')
grid(app.VoltageAxes, 'on')

% Enable fields and spinners
app.CursorSpinnerLabel.Enable = 'on';
app.CursorNumberSpinner.Enable = 'on';
app.DataInfoMenu.Enable = 'on';
app.ExporttomatMenu.Enable = 'on';
app.RestingPotentialField.Enable = 'on';
app.RestingPotentialmVLabel.Enable = 'on';

% Enable analysis and fittings
app.IVgraphMenu.Enable = 'on';
app.HistogramMenu.Enable = 'on';
app.ConductancegraphMenu.Enable = 'on';
app.PSDMenu.Enable = 'on';
app.DependenceAnalysisMenu.Enable = 'on';
app.ExponentialMenu.Enable = 'on';
app.GaussianMenu.Enable = 'on';
app.LinearMenu.Enable = 'on';
app.BoltzmannMenu.Enable = 'on';
app.ExperimentalconditionField.Enable = 'on';
app.ExperimentalconditionLabel.Enable = 'on';
app.CellCapacitancepFLabel.Enable = 'on';
app.CellCapacitanceField.Enable = 'on';
app.UITable.Enable = 'on';

% Display UIfigure over other windows
figure(app.EDAmatUIFigure)
end
