%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function LoadFileMenuSelected_m(app)
% Choose a file to load
[app.fileName, path]=uigetfile({'*.edh','Elements data header file';'*.abf','Axon binary file';'*.mat','MATLAB file'},'Multiselect','on');

% Display UIfigure over other windows
figure(app.EDAmatUIFigure)

% If no file was selected, exit
if path ~= 0
  
  % Reset variables
  LoadControls(app);
  
  % Check if more than one file was selected (if it is, fileName is a
  % cell array). It is possible to load more tan one .abf file of
  % different length but same number of sweeps; in this case raw data
  % will be averaged. Loading of more than one .edh or .mat file is not
  % implemented
  if iscell(app.fileName)
    
    fileHeadAbf = zeros(1,length(app.fileName));
    fileHeadMat = zeros(1,length(app.fileName));
    % Check the type of selected files
    for j = 1:length(app.fileName)
      fileHead = app.fileName{j};
      % headers contain 1 where j-th file is of their type
      fileHeadAbf(j) = strcmpi(fileHead(end-3:end),".abf");
      fileHeadMat(j) = strcmpi(fileHead(end-3:end),".mat");
    end
    
    % Check if all of the files are .abf...
    if length(find(fileHeadAbf)) == length(app.fileName)
      
      % Allocate a struct in order to store data of different length
      qq = struct([]);
      % Load every selected file (backward indexing to preallocate)
      for idx = length(app.fileName):-1:1
        % Load 1 file
        [d0, si, app.infoAbfLoad] = abfload(fullfile(path, app.fileName{idx}), 'doDispInfo', false);
        % Store current and voltage raw data in the temporay struct
        % d0(signal length, channel number, number of sweeps)
        qq(idx).I = d0(:,1,:);
        qq(idx).V = d0(:,2,:);
        % Get data minimum dimensions
        [xDim(idx), yDim(idx), zDim(idx)] = size(qq(idx).I);
      end
      % Cut the length to the shortest signal
      lengthMin = min(xDim);
      % Check if other dimension (number of sweeps, number of
      % channels) coincide...
      if all(zDim(1) == zDim) && all(yDim(1) == yDim)
        % Backward indexing to preallocate
        for j = length(app.fileName):-1:1
          % Construct a data matrix to be averaged
          % d(signal length, channel number, number of sweeps, number of loaded files)
          d(:,1,:,j) = qq(j).I(1:lengthMin,:,:);
          d(:,2,:,j) = qq(j).V(1:lengthMin,:,:);
        end
        % Average raw data
        d = mean(d,4);
        % Plot data
        LoadAbfActions(app, d, si)
      else
        %... if not, exit
        errordlg('Error: files must have same dimensions except length')
      end
      
    elseif length(find(fileHeadMat)) == length(app.fileName)
      % ...else check if they are all .mat
      errordlg('Error: too many .mat files')
      % Only 1 .mat file can be loaded
      
    else
      % ...if .mat and .abf files were selected together, display an
      % error (operations ecxecuted downstream are different for the
      % two types of files)
      errordlg('Error: files of different type')
    end
    
  else
    % Only one file selected
    if strcmpi(app.fileName(end-3:end),".edh")
      % Check if it is a .edh file and in case parse it and load the data
      [current, voltage, time, dataInfo] = loadEdh(fullfile(path, app.fileName));
      % Plot data
      LoadEdhActions(app, current, voltage, time, dataInfo);
      
    elseif strcmpi(app.fileName(end-3:end),".abf")
      % Check if it is a .abf file and in case load it
      [d, si, app.infoAbfLoad] = abfload(fullfile(path, app.fileName), 'doDispInfo', false);
      % Plot data
      LoadAbfActions(app, d, si);
      
    elseif strcmpi(app.fileName(end-3:end),".mat")
      % Check if it is a .mat file and in case load it
      load(fullfile(path, app.fileName), 'Data')
      % Plot data
      LoadMatActions(app, Data);
      
    end
  end
end
end
