%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function MapDropDownValueChanged(app, event, dataPropertyName, tickPropertyName)
%%% This script changes axes mapping (linear, quadratic, square root,
%%% logarithmic) in AnalysisFigure

% Get plotted lines handles
plottedLines = get(app.AnalysisAxes, 'children');
linesNum = length(plottedLines);

% If there is at least one line, apply transformation
if (linesNum > 0)
  %% map data
  for lineIdx = 1:linesNum
    % Transform one line at a time
    plottedLine = plottedLines(lineIdx);
    % Get plotNumber assigned during call to assignDataToPlot, in order
    % to get original data and transform them
    dataIndex = get(plottedLine, 'userdata');
    
    if strcmpi(dataPropertyName, 'xdata')
      % Get x data
      x = app.plotXData{dataIndex};
    else
      % Get y data
      x = app.plotYData{dataIndex};
    end
    % Transform
    x = mapPlotData(x, event.Value);
    % Apply transformation
    set(plottedLine, dataPropertyName, x)
  end
  
  %% map axes
  if strcmpi(tickPropertyName, 'xtick')
    % Get x tick
    xtick = app.plotXTick;
    xticklabel = app.plotXTickLabel;
  else
    % Get y tick
    xtick = app.plotYTick;
    xticklabel = app.plotYTickLabel;
  end
  % Tranform
  xtick = mapPlotTicks(app, xtick, event.Value);
  % Apply transformation
  set(app.AnalysisAxes, tickPropertyName, xtick(~isnan(xtick)))
  set(app.AnalysisAxes, [tickPropertyName, 'label'], xticklabel);
end
end
