# EDA mat

INDEX
1) Introduction
2) Loading
3) Data information
4) Cursors handling
5) Other GUI fields
6) Fittings
7) Analysis
8) Exporting

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
1) Introduction
This is a GUI interface to load and analize electrophysiology traces recorded
with EDR (Elements Data Reader), as well as abf or mat files in Matlab.

Note: if you just want to load files recorded with EDR or exported with EDA
in Matlab, without using the GUI, you can just use loadEdh.m

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
2) Loading 

- EDH: select one edh file associated to .dat, .abf or .csv data files, saved
    with EDR or exported with EDA.

- ABF: select one or more files; in the latter case after loading, cut both 
    raw current and voltage data to the shortests between them and check if 
    other dimensions (in partiicular the number of sweeps) coincide; in this 
    case average raw data.
    Abf files are loaded with "abfload.m" (Collman-Hentschke)

- MAT: only one mat file can be loaded. The file must contain a "Data" 
    structure with fixed fields (e.g. fileName, samplingFrequency, etc) for
    raw data; it can also contain data coming from executed analysis or 
    parameters from fittings. 

Files of different type can't be loaded together.
Loading cleares AnalysisFigures but keeps cursors as they were set by the 
user, so that when loading the same or similar files, they are already  in 
the right position.

The following units of measure are used throughout the code:
Current     -> [nA]
Voltage     -> [mV]
Time        -> [ms]
Frequency   -> [kHz]
Conductance -> [uS]

After loading, some control is implemented in order to convert data to this 
units, but it's better if data already have these units.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
3) Data information

Display some basic data information coming from edh file, abf header, or mat
file (e.g. fileName, samplingFrequency, number of sweeps and number of
current channels)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
4) Cursors handling

0 to 10 cursors can be selected at the moment on CurrentAxes. You can 
easily change this option by changing the values in the CursorNumberSpinner 
Limits box in Matlab App Designer or assigning new ones to
app.CursorNumberSpinner.Limits. 
No cursors can be selected on AnalysisFigure.

- No cursor selected: analysis and fittings are executed on the whole 
    signal.

- 1 cursor selected: analysis and fittings are executed on the signal 
    starting from the position of the cursor to the end of the signal.

- 2 cursors selected: analysis and fittings are executed on the part of the 
    signal between the two cursors. 
    Warning: cursor 1 must be at the left of cursor 2.

- more than 2 cursors selected: fit n-1 sweeps (n = number of 
    cursors), each one from position of cursor 1 to position of cursor
    n (e.g.: 3 cursors selected, then the first 2 sweeps will be 
    fitted, the first between cursors 1 and 2, the second between cursors 
    1 and 3). This functionality is not implemented for analysis.
    Warning: cursor 1 must be at the left of all of the other cursors.

Cursors can be moved with the x_cursorSpinner field or by dragging them 
with your mouse. 

                              << WARNING >>
Matlab 2019b still doesn't support zoom or mouse pointer properties setting 
for UIfigures, so when selecting axes toolbar buttons for zooming or 
panning, dragging of cursors couldn't be disabled (at least, another way 
couldn't be find). For this reason when clicking on mouse to drag a cursor,
panning and zooming are disabled a priori. Consequently, zooming with 
cursors selected could be tricky and we therefore suggest to zoom first and 
to select and move cursors only after. We hope this functionality will be 
added soon in Matlab so that this problem can be fixed.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
5) Other GUI fields

- Resting potential: resting or Nernst's inversion potential of the cell in
    mV, used in conductance analysis to compute conductance as I/(V-Ek). 
    Default value is 0 mV.

- Experimental condition: field used to save the experimental condition of 
    acquired data (e.g. wild type, mutant, etc), stored in "Data" structure
    when exporting.

- Cell capacitance: field used to store cell capacitance values for 
    normalization of data. Default value is 1 pF.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
6) Fittings

Fittings can be done on raw current data (in this case they are plotted on 
CurrentAxes) or on analysis data (in this case they are plotted on 
AnalysisFigure). Before fitting, a uicontrol menu is displayed to allow the 
user to do the fitting on data transformed in quadratic or logarithmic 
scale on both axes; if any of input data is less or equal to zero, 
logarithmic transformation is disabled. At the start of a fit on raw 
current data, controls on cursors are executed (cursors use has already 
been discussed in Section 3).

If data to be fit has more sweeps, the FittedSweepSpinner will be enabled, 
allowing the user to select which fitted sweep to display (together with
fitting parameters).

Fittings are obtained using least squares minimization through Matlab's 
fminsearch function. At the moment 4 type of fittings are implemented:

- Exponential
    
    > Single exponential, with model: B+A*exp(-xdata/tau)

    > Bi-exponential: (B1+A1*exp(-xdata/tau1))+(B2+A2*exp(-xdata/tau2))

- Gaussian

    >  A/(sqrt(2*pi)*sigma)*exp(-0.5*(((xdata-mu)/sigma).^2))

- Linear

    > m*xdata+b

- Boltzmann

    > bottom + (top-bottom)./(1+exp((vH-xdata)/slope))

These models are implemented in the "[fit_type]_eval" functions; if you wish 
to implement different models or change parameters, you can modify these 
functions as you prefer. 
To add new fittings on CurrentAxes, create a new callback in App Designer, 
a new "[fit_type]MenuSelected_m" script (called by the callback) and a new 
"[fit_type]_eval" function, this one to be given to "fminsearch_error"
function for least squares minimization. Do the same for AnalysisAxes, 
where however things work slightly differently, since there is the need to 
save the data somewhere ('userdata' axes property was chosen in this case) 
in order to pass them to the "app" object when exporting. This is because 
the workspaces of EDAmatUIFigure and AnalysisFigure don't communicate.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
7) Analysis

Analysis are done on raw current data, which can be normalized to their max 
values or to the cell capacitance. At the start, controls on cursors are 
executed (cursors use has already been discussed in Section 3).

5 types of analysis are implemented at the moment:

- I/V graph: it can be calculated in the mean, max or min point of every 
    sweep.

- Conductance graph: also this can be calculated in the mean, max or min 
    point of every sweep. Plus, the conductance graph can be made using the 
    tail currents, this way avoiding the depedence of the current from the 
    voltage stimulus.

- Histogram : calculates the number of current values belonging to 25 bins
    for every sweep.

- PSD: calculates the power spectral density for every sweep of the current 
    signal. Welch's method was implemented: every sweep is cut in 8 windows 
    with 50% overlap and multiplied by a Hamming window before applying 
    fft; after this, the resulting windows tranforms are averaged and DC 
    component is deleted by removing the first sample of the signal.

- Dependence graph: this analysis allows to plot I,V (with or without 
    normalization and calculated in mean, max or min point) and parameters 
    of raw current data fittings one against the other.

Executing an analysis opens a new AnalysisFigure object, with the analysis
name and an incremental number. This makes that one can know where data 
were stored when exporting to a mat file, since closing an AnalysisFigure 
clears its data and parameters from the structure they were temporarily
stored in.
Another feature of AnalysisFigure is the control of axes mapping: plotted
data visualization can be set in quadratic, square root or logarithmic 
scale (linear scale is set by default). This is useful for example when 
doing a linear fitting with y logarithmic transformation on an exponential 
signal: when switching to logarithmic y axis mapping, two straight lines 
(the signal and the fitting) will be displayed.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
8) Exporting

After loading, analyzing and fitting current data from an abf file, it is 
possibile to export raw data, data informations, analysis data and fitting
parameters in a mat file consisting of one "Data" struct containing all of 
this information. The export "Data" struct is built so as to allow loading 
of the exported mat file in this GUI, but data can be extracted by the user 
with dot indexing notation, allowing further analysis in Matlab.
