%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function SelectDataFittedToPlot(app)
%%% Script called by Analysis Menu and FittedSweepSpinnerValueChanging

% Check if there is more than 1 curve fitted, in this case enable the
% spinner
if size(app.fitYResults,2)>1
  app.FittedSweepSpinner.Enable = 'on';
  app.FittedSweepSpinnerLabel.Enable = 'on';
else
  app.FittedSweepSpinner.Enable = 'off';
  app.FittedSweepSpinnerLabel.Enable = 'off';
  % First sweep is plotted by deafult
  app.FittedSweepSpinner.Value = 1;
end

% hold on
set(app.fitAxes,'NextPlot','add')
% Exract the selected sweep
x = app.fitXMappedResults(:, app.fittedSpinner);
y = app.fitYMappedResults(:, app.fittedSpinner);

if strcmpi(app.tag, 'GUIFigure')
  
  % Get fitted curves
  plottedLines = get(app.fitAxes,'children');
  % If i have previous fittings I update them, otherwise i plot them; the
  % number of fittings is given by the difference between all of the
  % plotted lines and the sum between lines due to current data and
  % cursors lines and labels
  if (length(plottedLines)-length(app.cursorsLine)*2) > size(app.current,2)
    set(app.fittedLine, 'xdata', x, 'ydata', y)
  else
    app.fittedLine = plot(app.fitAxes, x, y,'r--','linewidth',2);
  end
  
elseif strcmpi(app.tag, 'AnalysisFigure')
  
  % Get fitted curves
  fittedDataArrays = find(app.plotDataType == 1, 1);
  % If i have previous fittings I update them, otherwise i plot them; I
  % know how many fittings there are from the data type (=0 -> original
  % data; =1 -> fitting)
  if isempty(fittedDataArrays)
    app.fittedLine = plot(app.fitAxes, x, y,'r--','linewidth',2);
  else
    set(app.fittedLine, 'xdata', x, 'ydata', y,'userdata','')
  end
  % Pass fitted data to AnalysisFigure
  app.assignDataToPlot(x,y,1)
  
end

% Underline the parameters of the selected sweep in
tabCol = repmat([1 1 1],size(app.UITable.Data,1),1);
tabCol(app.fittedSpinner,3) = 0; % [1 1 0] -> yellow
set(app.UITable,'BackgroundColor',tabCol)
end
