%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function SelectFitCoords(app)
%%% Controls on cursors
cursNum = app.CursorNumberSpinner.Value;
app.cursorsOk = true;

% Fitting Variables dimensions
app.fitVariableLength = 1000;
app.fitVariableNumber = size(app.current,2);

if cursNum == 0
  %%% If no cursor is selected, then fit the whole signal
  % Start
  x_cur1 = 0;
  % End
  x_cur2 = length(app.dataTimeVect);
  
  %%% Extracting current values
  % Indices
  app.cursorsTimeVect = (app.dataTimeVect >= x_cur1(1) & app.dataTimeVect <= x_cur2(1));
  % Time values (in a matrix of the same dimension as current data)
  app.fitXCoords = repmat(app.dataTimeVect(app.cursorsTimeVect), 1, size(app.current, 2));
  app.fitYCoords = app.current(app.cursorsTimeVect, :);
  
elseif cursNum == 1
  %%% If just one cursor is selected, fit the signal starting from that
  %%% point
  % Start
  x_cur1 = get(app.cursorsLine(1),'xdata');
  % End
  x_cur2 = length(app.dataTimeVect);
  
  %%% Extracting current values
  % Indices
  app.cursorsTimeVect = (app.dataTimeVect >= x_cur1(1) & app.dataTimeVect <= x_cur2(1));
  % Time values (in a matrix of the same dimension as current data)
  app.fitXCoords = repmat(app.dataTimeVect(app.cursorsTimeVect), 1, size(app.current, 2));
  app.fitYCoords = app.current(app.cursorsTimeVect, :);
  
elseif cursNum == 2
  %%% If 2 cursors are selected, then fit the signal between them
  % Start
  x_cur1 = get(app.cursorsLine(1),'xdata');
  % End
  x_cur2 = get(app.cursorsLine(2),'xdata');
  % Control on cursors position
  if x_cur1(1)>=x_cur2(1)
    uialert(app.EDAmatUIFigure, 'Cursor 1 cannot be to the right of cursor 2','Error')
    app.cursorsOk = false;
    return
  end
  
  
  %%% Extracting current values
  % Indices
  app.cursorsTimeVect = (app.dataTimeVect >= x_cur1(1) & app.dataTimeVect <= x_cur2(1));
  % Time values (in a matrix of the same dimension as current data)
  app.fitXCoords = repmat(app.dataTimeVect(app.cursorsTimeVect), 1, size(app.current, 2));
  app.fitYCoords = app.current(app.cursorsTimeVect, :);
  
elseif cursNum > 2
  % if more than 2 cursors are selected, fit n-1 sweeps (n= number of
  % cursors), each one from position of cursor 1 to position of cursor
  % n (e.g.: 3 cursors selected, then the first 2 sweeps will be
  % fitted, the first between cursors 1 and 2, the second between cursors
  % 1 and 3)
  
  % Get cursors position
  x_cur = cell2mat(get(app.cursorsLine,'xdata'));
  x_cur = x_cur(:,1);
  
  if find(x_cur(1) >= x_cur(2:end))
    uialert(app.EDAmatUIFigure, 'Cursor 1 cannot be to the right of the other cursors', 'Error')
    app.cursorsOk = false;
    return
  end
  
  % Fit n-1 sweeps
  app.selectedSweepNum = cursNum-1;
  % Allocate variables
  app.fitXCoords = cell(1,app.selectedSweepNum);
  app.fitYCoords = cell(1,app.selectedSweepNum);
  
  for idx = 2: cursNum
    %%% Extracting current values
    % Indices
    app.cursorsTimeVect = (app.dataTimeVect >= x_cur(1) & app.dataTimeVect <= x_cur(idx));
    % Time values (in a matrix of the same dimension as current data)
    app.fitXCoords{idx-1} = app.dataTimeVect(app.cursorsTimeVect);
    app.fitYCoords{idx-1} = app.current(app.cursorsTimeVect,idx-1);
  end
  % Fit n-1 sweeps (next for cycles are from 1 to app.fitVariableNumber)
  app.fitVariableNumber = app.selectedSweepNum;
end

% Update sweep spinner limits
if ~isempty(app.selectedSweepNum)
  app.FittedSweepSpinner.Limits(2) = min(size(app.current,2), app.selectedSweepNum);
else
  app.FittedSweepSpinner.Limits(2) = size(app.current,2);
end

app.analysisWindowClosed = false;
end
