%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function SelectTransformationForFitting(app)
%%% SelectDataTransformation
% Popup dialog to choose coordinates transformation

d = dialog('Position',[300 200 250 200],'Name','Fitting Data Selection','CloseRequestFcn',{@DataSelectionWindowClosing, app});
txt1 = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[25 120 150 50],...
  'String','Select the transformation');
txtX = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[50 90 10 40],...
  'String','x: ');
txtY = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[50 50 10 40],...
  'String','y: ');

% If any of the data to be fitted is negative or equal to zero, disable
% logarithmic transformation, for x and y separated
app.fitMirrorXResults = 0;
app.fitMirrorYResults = 0;
% X
if any(app.fitXCoords(:) <= 0)
  popupXStringTrasf = {'Linear','Quadratic (^2)'};
  app.fitMirrorXResults = 1;
else
  popupXStringTrasf = {'Linear','Quadratic (^2)','Logarithmic (log)'};
end
% Y
if any(app.fitYCoords(:) <= 0)
  popupYStringTrasf = {'Linear','Quadratic (^2)'};
  app.fitMirrorYResults = 1;
else
  popupYStringTrasf = {'Linear','Quadratic (^2)','Logarithmic (log)'};
end

popupX = uicontrol('Parent',d,...
  'Style','popup',...
  'Position',[75 90 100 40],...
  'String',popupXStringTrasf,...
  'Callback',{@popupX_callback,app});

popupY = uicontrol('Parent',d,...
  'Style','popup',...
  'Position',[75 50 100 40],...
  'String',popupYStringTrasf,...
  'Callback',{@popupY_callback,app});

btn = uicontrol('Parent',d,...
  'Style','pushbutton',...
  'Position',[89 20 70 25],...
  'String','Select',...
  'Callback',{@select_btn_callback,app});

% 1-> Default: linear transformation
app.fitXTrasfType = 1;
app.fitYTrasfType = 1;

% Wait for d to close before running to completion
uiwait(d);
end

function popupX_callback(popupX,~,app)

% Select transformation on x axis
idx = popupX.Value;
popup_items = popupX.String;
choice = string(popup_items{idx});
if choice == "Linear"
  app.fitXTrasfType = app.TRANSF_TYPE_LIN;
  
elseif startsWith(choice, "Quadratic")
  app.fitXTrasfType = app.TRANSF_TYPE_QUAD;
  
elseif startsWith(choice, "Logarithmic")
  app.fitXTrasfType = app.TRANSF_TYPE_LOG;
end

end

function popupY_callback(popupY,~,app)

% Select transformation on y axis
idx = popupY.Value;
popup_items = popupY.String;
choice = string(popup_items{idx});
if choice == "Linear"
  app.fitYTrasfType = app.TRANSF_TYPE_LIN;
  
elseif startsWith(choice, "Quadratic")
  app.fitYTrasfType = app.TRANSF_TYPE_QUAD;
  
elseif startsWith(choice, "Logarithmic")
  app.fitYTrasfType = app.TRANSF_TYPE_LOG;
end

end

function select_btn_callback(~,~,app)

% Apply transformation on x axis
switch app.fitXTrasfType
  case app.TRANSF_TYPE_LIN
    app.fitXCoords = app.fitXCoords;
  case app.TRANSF_TYPE_QUAD
    app.fitXCoords = app.fitXCoords.^2;
  case app.TRANSF_TYPE_LOG
    app.fitXCoords = log(app.fitXCoords);
end

% Apply transformation on y axis
switch app.fitYTrasfType
  case app.TRANSF_TYPE_LIN
    app.fitYCoords = app.fitYCoords;
  case app.TRANSF_TYPE_QUAD
    app.fitYCoords = app.fitYCoords.^2;
  case app.TRANSF_TYPE_LOG
    app.fitYCoords = log(app.fitYCoords);
end

% close dialog
delete(gcf)

end
