%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function SelectTransformationFor_EXP_Fitting(app)
%%% SelectDataTransformation
% Popup dialog to choose coordinates transformation & type of exponential
% fitting

d = dialog('Position',[300 200 250 250],'Name','Fitting Data Selection','CloseRequestFcn',{@DataSelectionWindowClosing, app});
txt1 = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[25 170 150 50],...
  'String','Select the transformation');
txtX = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[50 150 10 40],...
  'String','x: ');
txtY = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[50 120 10 40],...
  'String','y: ');
txtExpType = uicontrol('Parent',d,...
  'Style','text',...
  'Position',[25 70 150 40],...
  'String','Select exponential type');

popupStringTrasf = {'Linear','Quadratic (^2)','Logarithmic (log)'};
popupStringExpType = {'Single exponential','Bi-exponential'};

popupX = uicontrol('Parent',d,...
  'Style','popup',...
  'Position',[75 150 100 40],...
  'String',popupStringTrasf,...
  'Callback',{@popupX_callback,app});

popupY = uicontrol('Parent',d,...
  'Style','popup',...
  'Position',[75 120 100 40],...
  'String',popupStringTrasf,...
  'Callback',{@popupY_callback,app});

popupExpType = uicontrol('Parent',d,...
  'Style','popup',...
  'Position',[75 50 100 40],...
  'String',popupStringExpType,...
  'Callback',{@popupExpType_callback,app});

btn = uicontrol('Parent',d,...
  'Style','pushbutton',...
  'Position',[89 20 70 25],...
  'String','Select',...
  'Callback',{@select_btn_callback,app});

% 1-> Default: linear transformation
app.fitXTrasfType = 1;
app.fitYTrasfType = 1;
% 1-> Default: single exponential
app.expType       = 1;

% Wait for d to close before running to completion
uiwait(d);
end

function popupX_callback(popupX,~,app)

% Set transformation on x axis
idx = popupX.Value;
popup_items = popupX.String;
choice = string(popup_items{idx});
if choice == "Linear"
  app.fitXTrasfType = app.TRANSF_TYPE_LIN;
  
elseif startsWith(choice, "Quadratic")
  app.fitXTrasfType = app.TRANSF_TYPE_QUAD;
  
elseif startsWith(choice, "Logarithmic")
  app.fitXTrasfType = app.TRANSF_TYPE_LOG;
end

end

function popupY_callback(popupY,~,app)

% Set transformation on y axis
idx = popupY.Value;
popup_items = popupY.String;
choice = string(popup_items{idx});
if choice == "Linear"
  app.fitYTrasfType = app.TRANSF_TYPE_LIN;
  
elseif startsWith(choice, "Quadratic")
  app.fitYTrasfType = app.TRANSF_TYPE_QUAD;
  
elseif startsWith(choice, "Logarithmic")
  app.fitYTrasfType = app.TRANSF_TYPE_LOG;
end

end

function popupExpType_callback(popupExpType,~,app)

% Set selected type of exponential
idx = popupExpType.Value;
popup_items = popupExpType.String;
choice = string(popup_items{idx});
if startsWith(choice, "Single")
  app.expType = app.EXP_TYPE_SINGLE;
  
elseif startsWith(choice, "Bi-")
  app.expType = app.EXP_TYPE_BI;
end

end

function select_btn_callback(~,~,app)

% Apply transformation on x axis
switch app.fitXTrasfType
  case app.TRANSF_TYPE_LIN %%% Linear
    app.fitXCoords = app.fitXCoords;
  case app.TRANSF_TYPE_QUAD %%% Quadratic
    app.fitXCoords = app.fitXCoords.^2;
  case app.TRANSF_TYPE_LOG %%% Logarithmic
    app.fitXCoords = log(app.fitXCoords);
end

% Apply transformation on y axis
switch app.fitYTrasfType
  case app.TRANSF_TYPE_LIN %%% Linear
    app.fitYCoords = app.fitYCoords;
  case app.TRANSF_TYPE_QUAD %%% Quadratic
    app.fitYCoords = app.fitYCoords.^2;
  case app.TRANSF_TYPE_LOG %%% Logarithmic
    app.fitYCoords = log(app.fitYCoords);
end

% Close dialog
delete(gcf)

end
