%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function assignDataToPlot_m(app, x, y, type)
%%% This script associates the plotted lines in AnalysisAxes to their 
%%% matching data, in order to have original data available to be 
%%% elaborated

% Every time it's called, the number of plotted lines is incremented
app.plotNumber = app.plotNumber+1; 
% Retrieving data from assignDataToPlot function (last line plotted)
app.plotXData{app.plotNumber} = x; 
app.plotYData{app.plotNumber} = y;
% Type = 0, original data; = 1, fittings
app.plotDataType(app.plotNumber) = type; 

% Retrieving data plotted, to assign the matching plotNumber
plottedLines = get(app.AnalysisAxes, 'children'); 
for lineIdx = 1:length(plottedLines)              
  plottedLine = plottedLines(lineIdx);
   % associating userData=plotNumber to the line without userData (which is
   % the last line plotted)
  if isempty(get(plottedLine, 'userdata'))
    set(plottedLine, 'userdata', app.plotNumber);
    
    % if a transformation is already selected, it's applied to the data
    x = mapPlotData(x, app.XMapDropDown.Value); 
    y = mapPlotData(y, app.YMapDropDown.Value); 
    set(plottedLine, 'xdata', x)
    set(plottedLine, 'ydata', y)
    break;
  end
end
end
