%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function fitTransformationSwitch(app)
%%% This script applies inverse transformation to data fitted in the
%%% selected transformation, in order to plot the fitting on the original
%%% data

% Apply transformation to original x data
switch app.fitXTrasfType
  case app.TRANSF_TYPE_LIN
    app.fitXMappedResults = app.fitXResults;
  case app.TRANSF_TYPE_QUAD
    app.fitXMappedResults = sqrt(app.fitXResults);
  case app.TRANSF_TYPE_LOG
    app.fitXMappedResults = exp(app.fitXResults);
end

% Apply transformation to original y data
switch app.fitYTrasfType
  case app.TRANSF_TYPE_LIN
    app.fitYMappedResults = app.fitYResults;
  case app.TRANSF_TYPE_QUAD
    app.fitYMappedResults = sqrt(app.fitYResults);
  case app.TRANSF_TYPE_LOG
    app.fitYMappedResults = exp(app.fitYResults);
end

% Replace complex values with Nans in order to plot
imagXMappedResults = imag(app.fitXMappedResults);
imagYMappedResults = imag(app.fitYMappedResults);

complexIndexes = (imagXMappedResults ~= 0) | (imagYMappedResults ~= 0);

app.fitXMappedResults(complexIndexes) = nan;
app.fitYMappedResults(complexIndexes) = nan;

% Overturn negative data transformed with quadratic transformation
if app.fitXTrasfType == app.TRANSF_TYPE_QUAD && app.fitMirrorXResults == 1
  app.fitXMappedResults = -app.fitXMappedResults;
end

if app.fitYTrasfType == app.TRANSF_TYPE_QUAD && app.fitMirrorYResults == 1
  app.fitYMappedResults = -app.fitYMappedResults;
end
end
