%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function x = mapPlotData(x, mapping)
% This function applies selected axes mapping transformation to data
% plotted on AnalysisFugure

switch mapping
    case 'Linear'
        % nothing to do
        
    case 'Quadratic'
        for idx = 1:length(x)
            if x(idx)>=0
                x(idx) = x(idx).^2;
            elseif x(idx)<0
                x(idx) = -(x(idx).^2);
            end
        end
        
    case 'Square root'
        q = length(x);
        % Transform only positive points
        x = sqrt(x(x>0));
        % Fill x vector with Nans (which won't be plotted), so that it
        % always has the same length
        if size(x,1) == 1
            % If x is a row vector
            x = [x; nan(1,q-length(x))];
        elseif size(x,2) == 1
            % If x is a column vector
            x = [x; nan(q-length(x),1)];
        end
        
    case 'Logarithmic'
        q = length(x);
        % Transform only positive points
        x = log(x(x>0));
        % Fill x vector with Nans (which won't be plotted), so that it
        % always has the same length
        if size(x,1) == 1
            % If x is a row vector
            x = [x; nan(1,q-length(x))];
        elseif size(x,2) == 1
            % If x is a column vector
            x = [x; nan(q-length(x),1)];
        end
        
end
