%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function mouseDownCallback(figHandle,varargin)

% Get the handles structure
handles = guidata(figHandle);

% Execute only if data was loaded and cursors selected
if ~isempty(handles)
    % Get the position where the mouse button was pressed (not released)
    % within the GUI
    currentPoint = get(figHandle, 'CurrentPoint');
    x            = currentPoint(1,1);
    y            = currentPoint(1,2);
    % Get the position of the axes within the GUI
    axesPos = get(handles.app.CurrentAxes,'Position');
    minx    = axesPos(1);
    miny    = axesPos(2);
    maxx    = minx + axesPos(3);
    maxy    = miny + axesPos(4);
    % Is the mouse down event within the axes?
    if x>=minx && x<=maxx && y>=miny && y<=maxy
        % Do we have graphics objects?
        if isfield(handles,'plotHandles')
            % Get the position of the mouse down event within the axes
            currentPoint = get(handles.app.CurrentAxes, 'CurrentPoint');
            x            = currentPoint(2,1);
            y            = currentPoint(2,2);
            % We are going to use the x and y data for each graphic object
            % and determine which one is closest to the mouse down event
            pp =  get(handles.app.CurrentAxes,'xtick');
            % minDist depends on zooming: when zoom is incremented, the
            % "area of capture" of the cursor decreases, leaving more space
            % for zooming (otherwise, as you can see below, when 
            % dist<minDist, zoom is disabled)
            minDist      = (pp(end)-pp(1))/8;
            minHndl      = 0;
            handIdx      = 0;
            for k=1:length(handles.plotHandles)
                xData = get(handles.plotHandles(k),'XData');
                dist  = abs(xData(1)-x);
                if dist<minDist
                    minHndl = handles.plotHandles(k);
                    minDist = dist;
                    handIdx = k;
                    % Disable zoom and pan so that they can't act while
                    % dragging cursors
                    pan(handles.app.CurrentAxes,'off')
                    zoom(handles.app.CurrentAxes,'off')
                end
            end
            % If we have a graphics handle that is close to the mouse down
            % event/position, then save the data
            if minHndl ~= 0
                handles.mouseIsDown     = true;
                handles.movingPlotHndle = minHndl;
                handles.prevPoint       = [x y];
                % Save selected cursor number
                handles.handIdx         = handIdx;
                guidata(figHandle,handles);
            else
                return
            end
            % Avoid axis drag when moving cursors
            axis(handles.app.CurrentAxes,[get(handles.app.CurrentAxes,'xlim') get(handles.app.CurrentAxes,'ylim')])
            
        end
    end
    
end

end
