%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function mouseMotionCallback(figHandle,varargin)

% Get the handles structure
handles = guidata(figHandle);

% If there is any cursor, underline the one to which mouse pointer is
% nearer, but only if the distance between cursor an mouse pointer is less
% than what it takes to move the selected cursor
if ~isempty(handles)
    % Reset cursors line specs
    set(handles.app.cursorsLine, 'color', 'r','LineWidth',0.5);
    currentPoint = get(handles.app.CurrentAxes, 'CurrentPoint');
    x = currentPoint(2,1);
    % Distance threshold under which is possible to move the cursors
    pp =  get(handles.app.CurrentAxes,'xtick');
    % minDist depends on zooming: when zoom is incremented, the "area of 
    % capture" of the cursor decreases, leaving more space for zooming 
    % (otherwise, as you can see in the MouseDownCallback script, when 
    % dist<minDist, zoom is disabled)
    minDist      = (pp(end)-pp(1))/8;
    % Compute mouse pointer distance from every cursor
    for k = length(handles.plotHandles):-1:1
        xData = get(handles.plotHandles(k),'XData');
        dist(k)  = abs(xData(1)-x);
    end
    % Check if there is any cursor
    if ~isempty(handles.plotHandles)
        % Get the index of the nearest cursor
        [dist,kDist] = min(dist);
        % Check if the distance between mouse pointer and cursor is under the threshold
        if dist<minDist
            % Underline cursor line
            set(handles.app.cursorsLine(kDist), 'color', 'y','LineWidth',2);
        end
    end
end

% If mouse is down, drag the cursor and keep it underlined
if isfield(handles,'mouseIsDown')
    if handles.mouseIsDown
        currentPoint = get(handles.app.CurrentAxes, 'CurrentPoint');
        x            = currentPoint(2,1);
        y            = currentPoint(2,2);
        % Compute the displacement from previous position to current
        xDiff = x - handles.prevPoint(1);
        % Adjust this for the data corresponding to movingPlotHndle
        xData = get(handles.movingPlotHndle,'XData');
        % Update line position
        set(handles.movingPlotHndle,'XData',xData+xDiff);
        handles.prevPoint = [x y];
        % Cursor is underlined while selected
        set(handles.app.cursorsLine(kDist), 'color', 'y','LineWidth',2);
        
        % Save the data
        handles.X = xData(1)+xDiff;
        guidata(figHandle,handles);
    end
    
end
