%   Copyright (C) 2019 Eugenio Ricci
%   Copyright (C) 2020 Filippo Cona
%
%   This file is part of EDAmat.
%
%   EDAmat is free software: you can redistribute it and/or modify
%   it under the terms of the GNU Lesser General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   EDAmat is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public License
%   along with EDAmat.  If not, see <http://www.gnu.org/licenses/>.

function mouseUpCallback(figHandle,varargin)

% Get the handles structure
handles = guidata(figHandle);

if isfield(handles,'mouseIsDown')
    if handles.mouseIsDown
        
        %%% For speed and stability reasons cursor label, drop down menu
        %%% and spinner are updated at mouse release instead of at mouse
        %%% motion
        % Update drop down menu with selected cursor
        handles.app.CursorDropDown.Value = handles.app.CursorDropDown.Items(handles.handIdx);
        % Update cursor spinner box value
        if handles.X < handles.app.x_cursorSpinner.Limits(2) && handles.X > handles.app.x_cursorSpinner.Limits(1)
            handles.app.x_cursorSpinner.Value = handles.X;
        end
        % Update cursor label position
        delete(handles.app.curLabel(handles.handIdx))
        curLabY = get(handles.app.CurrentAxes,'ylim');
        handles.app.curLabel(handles.handIdx) = text(handles.app.CurrentAxes,handles.X-0.05,curLabY(2)+curLabY(2)*0.1,num2str(handles.handIdx),'Color','red');
        set(handles.app.curLabel(handles.handIdx),'userdata',"cursor")
        
        % Reset all moving graphic fields
        handles.mouseIsDown     = false;
        handles.movingPlotHndle = [];
        handles.prevPoint       = [];
        handles.handIdx         = [];
        % Save the data
        guidata(figHandle,handles);
        
    end
end

end